from .io import dump
from .io import dumps
from .io import load
from .io import loads
from .validation import validate_inifile_schema

__version__ = "2.1.1"
